require 'socket'
require 'json'

module Richpresence
  class Opcode
    HANDSHAKE = 0
    FRAME = 1
  end

  class Ipc
    def initialize
      @socket = UNIXSocket.new("#{ipc_path}discord-ipc-0")
    end

    def send(opcode, payload)
      @socket.write(encode(opcode, payload))
      decode(@socket.recvfrom(1024).first)
    end

    def encode(opcode, payload)
      payload[:nonce] = format '%.20f', Time.now
      payload = payload.to_json
      [opcode, payload.length].pack('ii<') + payload
    end

    def decode(data)
      code, = data[0..3].unpack 'i<'
      [code, data[8..-1]]
    end

    def ipc_path
      %w[XDG_RUNTIME_DIR TMPDIR TMP TEMP].each do |directory|
        directory = ENV[directory]
        return directory if directory
      end

      '/tmp'
    end
  end
end