require_relative 'ipc'
require_relative 'errors'
require 'hue'

module Richpresence
  class Client
    def initialize(client_id)
      @client_id = client_id.to_s
      @ipc = Richpresence::Ipc.new
    end

    def login
      payload = {
        v: 1,
        client_id: @client_id
      }

      @ipc.send(Richpresence::Opcode::HANDSHAKE, payload)
    end

    def activity=(params)
      payload = {
        cmd: 'SET_ACTIVITY',
        args: {
          activity: params,
          pid: Process.pid
        }
      }

      run 'Setting activity...'
      response = JSON.parse @ipc.send(Richpresence::Opcode::FRAME, payload)[1]

      # If there is an error
      code = response['data']['code']
      if code
        error = Richpresence::Errors.parse_error_code(code)
        bad "An error occured: #{error}"
        exit code
      end

      good 'Activity setted'
    end
  end
end
